KNodeTable

Struct KNodeTable 

pub struct KNodeTable<Id, Info> { /* private fields */ }
KNodeTable Implementation This uses a flattened approach whereby buckets are pre-allocated and indexed by their distance from the local Id as a simplification of the allocation based branching approach introduced in the paper.

Implementations

Source

impl<Id, Info> KNodeTable<Id, Info>
where Id: DatabaseId + Clone + 'static, Info: Clone + Debug + 'static,

pub fn new(id: Id, bucket_size: usize, hash_size: usize) -> KNodeTable<Id, Info>

Create a new KNodeTable with the provded bucket and hash sizes