pub struct KNodeTable<Id, Info> { /* private fields */ }Expand description
KNodeTable Implementation This uses a flattened approach whereby buckets are pre-allocated and indexed by their distance from the local Id as a simplification of the allocation based branching approach introduced in the paper.
Implementations
Sourceimpl<Id, Info> KNodeTable<Id, Info>
impl<Id, Info> KNodeTable<Id, Info>
Sourcepub fn new(id: Id, bucket_size: usize, hash_size: usize) -> KNodeTable<Id, Info>
pub fn new(id: Id, bucket_size: usize, hash_size: usize) -> KNodeTable<Id, Info>
Create a new KNodeTable with the provded bucket and hash sizes